@@ -25,10 +25,10 @@ class AsyncReader:
         # Otherwise get some new data and split it into lines, and return the first line.
         try:
             new_text = self._get_data()
-        except serial.serialutil.SerialException as e:
-            raise ReaderError(e)
-        except UnicodeEncodeError as e:
-            raise ReaderError(e)
+        except serial.serialutil.SerialException as exc:
+            raise ReaderError(exc) from exc
+        except UnicodeEncodeError as exc:
+            raise ReaderError(exc) from exc
 
         if not new_text:
             return None
@@ -37,6 +37,9 @@ class AsyncReader:
         new_text = new_text.replace("\r", "")
         new_text = new_text.replace("\0", "")
 
+        if not new_text:
+            return None
+
         lines = new_text.splitlines(keepends=True)
 
         lines[0] = self.partial_line + lines[0]
@@ -62,6 +65,7 @@ class AsyncReader:
         return self.text
 
     def clear_accumulate(self):
+        """Clear the accumulated text that is return in 'get_accumulate'"""
         self.text = ""
 
     @abstractmethod
@@ -106,8 +110,9 @@ class AsyncReaderUART(AsyncReader):
 
     #     raise SerialNoFullLine
 
-    def get_data(self):
-        return self.serial.read_until()
+    def _get_data(self):
+        t = self.serial.read_until()
+        return t.decode("utf-8")
 
 
 class AsyncReaderSocket(AsyncReader):
