@@ -1,12 +1,10 @@
 import subprocess
 import time
-
+import sys
 import argparse
 
 import pyhubctl
 
-from utils import error, print_color, TermColors
-
 # TODO: At one point uhubctl failed with the following error:
 # uhubctl: symbol lookup error: uhubctl: undefined symbol: libusb_free_container_id_descriptor
 # I restarted the NUC and it worked, but I don't know what went wrong.
@@ -44,7 +42,6 @@ class USBPortPower:
 
 
 def usbPowerCycle(usb_phys_port):
-
     usb_location = ".".join(usb_phys_port.split(".")[:-1])
     usb_port = usb_phys_port.split(".")[-1]
     print(" ".join(["uhubctl", "-a", "off", "-l", usb_location, "-p", usb_port]))
@@ -100,6 +97,22 @@ def power_on(usb_phys_port, print_output=False):
         return True
 
 
+def cli():
+    parser = argparse.ArgumentParser()
+    parser.add_argument(
+        "usb_physical_port", help="The physical port of the USB (1-1.1 for example)"
+    )
+    parser.add_argument("action", choices=["on", "off"])
+
+    args = parser.parse_args()
+
+    p = USBPortPower(args.usb_physical_port)
+    if args.action == "on":
+        p.on()
+    else:
+        p.off()
+
+
 def main():
     #  Power cycle UART USB port
     print("Power cycling UART")
@@ -114,9 +127,9 @@ def main():
     result = usbPowerCycle(args.usb_physical_port)
 
     if True:
-        print_color(TermColors.GREEN, "Success")
+        print("Success")
     else:
-        error("USB power cycle failed")
+        sys.exit("USB power cycle failed")
 
 
 if __name__ == "__main__":
